@@ -15,33 +15,47 @@
 ##' graph because of the way they are related to one another which can be
 ##' represented through the Law of Cosines.
 ##'
-##' The \code{openair} version of the Taylor Diagram has several enhancements
-##' that increase its flexibility. In particular, the straightforward way of
-##' producing conditioning plots should prove valuable under many circumstances
-##' (using the \code{type} option). Many examples of Taylor Diagrams focus on
-##' model-observation comparisons for several models using all the available
-##' data. However, more insight can be gained into model performance by
-##' partitioning the data in various ways e.g. by season, daylight/nighttime,
-##' day of the week, by levels of a numeric variable e.g. wind speed or by
-##' land-use type etc.
+##' The \code{openair} version of the Taylor Diagram has several
+##' enhancements that increase its flexibility. In particular, the
+##' straightforward way of producing conditioning plots should prove
+##' valuable under many circumstances (using the \code{type}
+##' option). Many examples of Taylor Diagrams focus on
+##' model-observation comparisons for several models using all the
+##' available data. However, more insight can be gained into model
+##' performance by partitioning the data in various ways e.g. by
+##' season, daylight/nighttime, day of the week, by levels of a
+##' numeric variable e.g. wind speed or by land-use type etc.
 ##'
-##' To consider several pollutants on one plot, a column identifying the pollutant name
-##' can be used e.g. \code{pollutant}. Then the Taylor Diagram can be plotted as (assuming
-##' a data frame \code{thedata}):
+##' To consider several pollutants on one plot, a column identifying
+##' the pollutant name can be used e.g. \code{pollutant}. Then the
+##' Taylor Diagram can be plotted as (assuming a data frame
+##' \code{thedata}):
 ##'
 ##' \code{TaylorDiagram(thedata, obs = "obs", mod = "mod", group = "model", type = "pollutant")}
 ##'
 ##' which will give the model performance by pollutant in each panel.
 ##'
-##' Note that it is important
-##' that each panel represents data with the same mean observed data
-##' across different groups. Therefore \code{TaylorDiagram(mydata,
-##' group = "model", type = "season")} is OK, whereas
-##' \code{TaylorDiagram(mydata, group = "season", type = "model")} is
-##' not because each panel (representing a model) will have four
-##' different mean values --- one for each season. Generally, the
-##' option \code{group} is either missing (one model being evaluated)
-##' or represents a column giving the model name.
+##' Note that it is important that each panel represents data with the
+##' same mean observed data across different groups. Therefore
+##' \code{TaylorDiagram(mydata, group = "model", type = "season")} is
+##' OK, whereas \code{TaylorDiagram(mydata, group = "season", type =
+##' "model")} is not because each panel (representing a model) will
+##' have four different mean values --- one for each
+##' season. Generally, the option \code{group} is either missing (one
+##' model being evaluated) or represents a column giving the model
+##' name. However, the data can be normalised using the
+##' \code{normalise} option. Normalisation is carried out on a per
+##' \code{group}/\code{type} basis making it possible to compare data
+##' on different scales e.g. \code{TaylorDiagram(mydata, group =
+##' "season", type = "model", normalise = TRUE)}. In this way it is
+##' possible to compare different pollutants, sites etc. in the same
+##' panel.
+##'
+##' Also note that if multiple sites are present it makes sense to use
+##' \code{type = "site"} to ensure that each panel represents an
+##' individual site with its own specific standard deviation etc. If
+##' this is not the case then select a single site from the data first
+##' e.g. \code{subset(mydata, site == "Harwell")}.
 ##'
 ##' @param mydata A data frame minimally containing a column of observations
 ##'   and a column of predictions.
@@ -50,7 +64,7 @@
 ##' @param mod A column of model predictions. Note, \code{mod} can be
 ##' of length 2 i.e. two lots of model predictions. If two sets of
 ##' predictions are are present e.g. \code{mod = c("base",
-##' "revised")}, then arrows are shown on the Taylor Diafram which
+##' "revised")}, then arrows are shown on the Taylor Diagram which
 ##' show the change in model performance in going from the first to
 ##' the second. This is useful where, for example, there is interest
 ##' in comparing how one model run compares with another using
@@ -60,34 +74,48 @@
 ##'   different models and can be a factor or character. The total number of
 ##'   models compared will be equal to the number of unique values of
 ##'   \code{group}.
-##' @param type \code{type} determines how the data are split i.e. conditioned,
-##'   and then plotted. The default is will produce a single plot using the
-##'   entire data. Type can be one of the built-in types as detailed in
-##'   \code{cutData} e.g. "season", "year", "weekday" and so on. For example,
-##'   \code{type = "season"} will produce four plots --- one for each season.
+##' @param type \code{type} determines how the data are split
+##' i.e. conditioned, and then plotted. The default is will produce a
+##' single plot using the entire data. Type can be one of the built-in
+##' types as detailed in \code{cutData} e.g. "season", "year",
+##' "weekday" and so on. For example, \code{type = "season"} will
+##' produce four plots --- one for each season.
 ##'
-##' It is also possible to choose \code{type} as another variable in the data
-##'   frame. If that variable is numeric, then the data will be split into four
-##'   quantiles (if possible) and labelled accordingly. If type is an existing
-##'   character or factor variable, then those categories/levels will be used
-##'   directly. This offers great flexibility for understanding the variation
-##'   of different variables and how they depend on one another.
+##' It is also possible to choose \code{type} as another variable in
+##' the data frame. If that variable is numeric, then the data will be
+##' split into four quantiles (if possible) and labelled
+##' accordingly. If type is an existing character or factor variable,
+##' then those categories/levels will be used directly. This offers
+##' great flexibility for understanding the variation of different
+##' variables and how they depend on one another.
 ##'
-##' Type can be up length two e.g. \code{type = c("season", "weekday")} will
-##'   produce a 2x2 plot split by season and day of the week. Note, when two
-##'   types are provided the first forms the columns and the second the rows.
-##' @param normalise Should the data be normalised by dividing the standard
-##'   deviation of the observations? The statistics can be normalised (and
-##'   non-dimensionalised) by dividing both the RMS difference and the standard
-##'   deviation of the \code{mod} values by the standard deviation of the
-##'   observations (\code{obs}). In this case the "observed" point is plotted
-##'   on the x-axis at unit distance from the origin. This makes it possible to
-##'   plot statistics for different species (maybe with different units) on the
-##'   same plot.
-##' @param cols Colours to be used for plotting. Options include "default",
-##'   "increment", "heat", "spectral", "hue", "brewer1", "greyscale" and user
-##'   defined (see \code{openColours} for more details). The same line colour
-##'   can be set for all pollutant e.g. \code{cols = "black"}.
+##' Type can be up length two e.g. \code{type = c("season",
+##' "weekday")} will produce a 2x2 plot split by season and day of the
+##' week. Note, when two types are provided the first forms the
+##' columns and the second the rows.
+##'
+##' Note that often it will make sense to use \code{type = "site"}
+##' when multiple sites are available. This will ensure that each
+##' panel contains data specific to an individual site.
+##' @param normalise Should the data be normalised by dividing the
+##' standard deviation of the observations? The statistics can be
+##' normalised (and non-dimensionalised) by dividing both the RMS
+##' difference and the standard deviation of the \code{mod} values by
+##' the standard deviation of the observations (\code{obs}). In this
+##' case the "observed" point is plotted on the x-axis at unit
+##' distance from the origin. This makes it possible to plot
+##' statistics for different species (maybe with different units) on
+##' the same plot. The normalisation is done by each
+##' \code{group}/\code{type} combination.
+##' @param cols Colours to be used for plotting. Useful options for
+##' categorical data are avilable from \code{RColorBrewer} colours ---
+##' see the \code{openair} \code{openColours} function for more
+##' details. Useful schemes include "Accent", "Dark2", "Paired",
+##' "Pastel1", "Pastel2", "Set1", "Set2", "Set3" --- but see
+##' ?\code{brewer.pal} for the maximum useful colours in each. For
+##' user defined the user can supply a list of colour names recognised
+##' by R (type \code{colours()} to see the full list). An example
+##' would be \code{cols = c("yellow", "green", "blue")}.
 ##' @param rms.col Colour for centred-RMS lines and text.
 ##' @param cor.col Colour for correlation coefficient lines and text.
 ##' @param arrow.lwd Width of arrow used when used for comparing two model outputs.
@@ -104,16 +132,16 @@
 ##' @param auto.text Either \code{TRUE} (default) or \code{FALSE}. If
 ##'   \code{TRUE} titles and axis labels will automatically try and format
 ##'   pollutant names and units properly e.g.  by subscripting the `2' in NO2.
-##' @param \dots Other graphical parameters are passed onto \code{cutData} and 
-##'   \code{lattice:xyplot}. For example, \code{TaylorDiagram} passes the option 
-##'   \code{hemisphere = "southern"} on to \code{cutData} to provide southern 
-##'   (rather than default northern) hemisphere handling of \code{type = "season"}. 
-##'   Similarly, common graphical parameters, such as \code{layout} for panel 
-##'   arrangement and \code{pch} and \code{cex} for plot symbol type and size, 
-##'   are passed on to \code{xyplot}. Most are passed unmodified, although there are 
-##'   some special cases where \code{openair} may locally manage this process. For 
-##'   example, common axis and title labelling options (such as \code{xlab}, \code{ylab}, 
-##'   \code{main}) are passed via \code{quickText} to handle routine formatting. 
+##' @param \dots Other graphical parameters are passed onto \code{cutData} and
+##'   \code{lattice:xyplot}. For example, \code{TaylorDiagram} passes the option
+##'   \code{hemisphere = "southern"} on to \code{cutData} to provide southern
+##'   (rather than default northern) hemisphere handling of \code{type = "season"}.
+##'   Similarly, common graphical parameters, such as \code{layout} for panel
+##'   arrangement and \code{pch} and \code{cex} for plot symbol type and size,
+##'   are passed on to \code{xyplot}. Most are passed unmodified, although there are
+##'   some special cases where \code{openair} may locally manage this process. For
+##'   example, common axis and title labelling options (such as \code{xlab}, \code{ylab},
+##'   \code{main}) are passed via \code{quickText} to handle routine formatting.
 ##' @export
 ##' @return As well as generating the plot itself, \code{TaylorDiagram} also
 ##'   returns an object of class ``openair''. The object includes three main
@@ -202,10 +230,10 @@
 ##'
 ##'
 TaylorDiagram <- function(mydata, obs = "obs", mod = "mod", group = NULL, type = "default",
-                          normalise = FALSE,  cols = "brewer1", 
+                          normalise = FALSE,  cols = "brewer1",
                           rms.col = "darkgoldenrod", cor.col = "black", arrow.lwd = 3,
                           key = TRUE, key.title = group, key.columns = 1,
-                          key.pos = "bottom", strip = TRUE, auto.text = TRUE, ...)
+                          key.pos = "right", strip = TRUE, auto.text = TRUE, ...)
 {
 
 
@@ -337,11 +365,6 @@ TaylorDiagram <- function(mydata, obs = "obs", mod = "mod", group = NULL, type =
 
     pol.name <- sapply(levels(mydata[ , group]), function(x) quickText(x, auto.text))
 
-
-    if (missing(key.columns)) if (npol < 5) key.columns <- npol else key.columns <- 4
-
-
-
     if (key & npol > 1 & !combine) {
 
         key <- list(points = list(col = myColors[1:npol]), pch = extra.args$pch, cex = extra.args$cex,
@@ -527,7 +550,7 @@ TaylorDiagram <- function(mydata, obs = "obs", mod = "mod", group = NULL, type =
               })
 
     #reset for extra.args
-    xyplot.args<- listUpdate(xyplot.args, extra.args)
+    xyplot.args<- openair:::listUpdate(xyplot.args, extra.args)
 
     #plot
     plt <- do.call(xyplot, xyplot.args)
